[gtk+] Rename time to time_ to avoid a scanner warning



commit 358a2b86758f411c839b303fedc143135e8f3f3e
Author: Johan Dahlin <johan gnome org>
Date:   Tue Feb 8 13:29:57 2011 -0200

    Rename time to time_ to avoid a scanner warning

 gtk/gtkdnd.c |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/gtk/gtkdnd.c b/gtk/gtkdnd.c
index 825008c..8c074c9 100644
--- a/gtk/gtkdnd.c
+++ b/gtk/gtkdnd.c
@@ -964,15 +964,15 @@ gtk_drag_update_cursor (GtkDragSourceInfo *info)
  * @widget: a #GtkWidget
  * @context: drag context
  * @target: format to retrieve the data in.
  * @time: timestamp of triggering event.
  *
  * Get the data for a drag or drop
  */
-void 
+void
 gtk_drag_get_data (GtkWidget      *widget,
 		   GdkDragContext *context,
 		   GdkAtom         target,
-		   guint32         time)
+		   guint32         time_)
 {
   GtkWidget *selection_widget;
 
@@ -983,7 +983,7 @@ gtk_drag_get_data (GtkWidget      *widget,
 
   g_object_ref (context);
   g_object_ref (widget);
-  
+
   g_signal_connect (selection_widget, "selection-received",
 		    G_CALLBACK (gtk_drag_selection_received), widget);
 
@@ -992,7 +992,7 @@ gtk_drag_get_data (GtkWidget      *widget,
   gtk_selection_convert (selection_widget,
 			 gdk_drag_get_selection (context),
 			 target,
-			 time);
+			 time_);
 }
 
 
@@ -964,15 +964,15 @@ gtk_drag_update_cursor (GtkDragSourceInfo *info)
  * @context: drag context
  * @target: format to retrieve the data in.
- * @time: timestamp of triggering event.
+ * @time_: timestamp of triggering event.
  *
  * Get the data for a drag or drop



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]